@@ -1,5 +1,5 @@
 import React, { useContext } from 'react';
-import { transContext } from '../widgets/JudgeTools';
+import { transContext } from '../widgets/JudgeSubmissionArea';
 import styled from '@emotion/styled';
 import { JudgeModel } from '../model';
 
