@@ -1,5 +1,5 @@
-export const TRANSLATOR_DOMAIN = 'jupyterlab_judge';
+export const TRANSLATOR_DOMAIN = 'jupyterlab-judge';
 export const DRIVE_NAME = 'judgedrive';
 export const BROWSER_NAME = 'judgebrowser';
 export const JUDGE_HIDDEN_FOLDER_NAME = '.jce-judge';
-export const PLUGIN_ID = 'jupyterlab_judge';
+export const PLUGIN_ID = 'jupyterlab-judge';
